==> tuia-treasure-center-api-1.8.4.2-bypass-20190115.084732-1-sources.jar: cn/tuia/tuia/treasure/center/api/dto/VideoDto.java <==
package cn.tuia.tuia.treasure.center.api.dto;

import java.io.Serializable;
import java.util.Date;

public class VideoDto implements Serializable {

    private static final long serialVersionUID = -6430756488779785945L;

    /**
     * 视频id
     */
    private Long id;

    /**
     * 视频类型，写死为1
     */
    private Integer newsType = 1 ;

    /**
     * 视频标题
     */
    private String title;

    /**
     * 视频图片地址
     */
    private String imageUrl;

    /**
     * 视频分类
     */
    private String channel;

    /**
     * 视频地址
     */
    private String newsUrl;

    /**
     * 媒体名称，作者名称
     */
    private String author;

    /**
     * 媒体名称，作者名称
     */
    private String authorUrl;


    /**
     * 点赞数
     */
    private Long starNum;

    /**
     * 阅读人数
     */
    private Long readNum;

    /**
     * 视频时长
     */
    private Integer videoTime;

    /**
     * 这个发布时间其实是第三方的创建时间
     */
    private Date publishTime;

    /**
     * 创建时间，即入库时间
     */
    private Date gmtCreate;

    /**
     * 视频来源
     */
    private Integer videoSource;

    /**
     * 是否点赞
     */
    private boolean isStar;

    /**
     * 视频分类
     */
    private String category;

    /**
     * 设置为推荐时间
     */
    private Date recommendTime;
    /**
     * 下架时间
     */
    private Date offTime;
    /**
     * 是否为推荐 0非推荐 1推荐
     */
    private Integer isRecommend;
    /**
     * 类别id
     */
    private Long tagId;

    public String getCategory() {
        return category;
    }

    public void setCategory(String category) {
        this.category = category;
    }

    public Integer getVideoSource() {
        return videoSource;
    }

    public String getChannel() {
        return channel;
    }

    public void setChannel(String channel) {
        this.channel = channel;
    }

    public void setVideoSource(Integer videoSource) {
        this.videoSource = videoSource;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Integer getNewsType() {
        return newsType;
    }

    public void setNewsType(Integer newsType) {
        this.newsType = newsType;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getImageUrl() {
        return imageUrl;
    }

    public void setImageUrl(String imageUrl) {
        this.imageUrl = imageUrl;
    }

    public String getNewsUrl() {
        return newsUrl;
    }

    public void setNewsUrl(String newsUrl) {
        this.newsUrl = newsUrl;
    }

    public String getAuthor() {
        return author;
    }

    public void setAuthor(String author) {
        this.author = author;
    }

    public Long getStarNum() {
        return starNum;
    }

    public void setStarNum(Long starNum) {
        this.starNum = starNum;
    }

    public Long getReadNum() {
        return readNum;
    }

    public void setReadNum(Long readNum) {
        this.readNum = readNum;
    }

    public Integer getVideoTime() {
        return videoTime;
    }

    public void setVideoTime(Integer videoTime) {
        this.videoTime = videoTime;
    }

    public Date getPublishTime() {
        return publishTime;
    }

    public void setPublishTime(Date publishTime) {
        this.publishTime = publishTime;
    }

    public String getAuthorUrl() {
        return authorUrl;
    }

    public void setAuthorUrl(String authorUrl) {
        this.authorUrl = authorUrl;
    }

    public boolean getIsStar() {
        return isStar;
    }

    public void setIsStar(boolean isStar) {
        this.isStar = isStar;
    }

    public Date getRecommendTime() {
        return recommendTime;
    }

    public void setRecommendTime(Date recommendTime) {
        this.recommendTime = recommendTime;
    }

    public Date getOffTime() {
        return offTime;
    }

    public void setOffTime(Date offTime) {
        this.offTime = offTime;
    }

    public Integer getIsRecommend() {
        return isRecommend;
    }

    public void setIsRecommend(Integer isRecommend) {
        this.isRecommend = isRecommend;
    }

    public Long getTagId() {
        return tagId;
    }

    public void setTagId(Long tagId) {
        this.tagId = tagId;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }
}

==> tuia-treasure-center-api-1.8.4.3-bypass-20190117.060601-7-sources.jar: cn/tuia/tuia/treasure/center/api/dto/VideoDto.java <==
package cn.tuia.tuia.treasure.center.api.dto;

import java.io.Serializable;
import java.util.Date;

public class VideoDto implements Serializable {

    private static final long serialVersionUID = -6430756488779785945L;

    /**
     * 视频id
     */
    private Long id;

    /**
     * 视频类型，写死为1
     */
    private Integer newsType = 1 ;

    /**
     * 视频标题
     */
    private String title;

    /**
     * 视频图片地址
     */
    private String imageUrl;

    /**
     * 视频分类
     */
    private String channel;

    /**
     * 视频地址
     */
    private String newsUrl;

    /**
     * 媒体名称，作者名称
     */
    private String author;

    /**
     * 媒体名称，作者名称
     */
    private String authorUrl;


    /**
     * 点赞数
     */
    private Long starNum;

    /**
     * 阅读人数
     */
    private Long readNum;

    /**
     * 视频时长
     */
    private Integer videoTime;

    /**
     * 这个发布时间其实是第三方的创建时间
     */
    private Date publishTime;

    /**
     * 创建时间，即入库时间
     */
    private Date gmtCreate;

    /**
     * 视频来源
     */
    private Integer videoSource;

    /**
     * 是否点赞
     */
    private boolean isStar;

    /**
     * 视频分类
     */
    private String category;

    /**
     * 设置为推荐时间
     */
    private Date recommendTime;
    /**
     * 下架时间
     */
    private Date offTime;
    /**
     * 是否为推荐 0非推荐 1推荐
     */
    private Integer isRecommend;
    /**
     * 类别id
     */
    private Long tagId;

    /** 是否新人推荐 0非推荐 1推荐*/
    private Integer isNewRecommend;
    /** 排序序号 */
    private Integer rank;

    public Integer getIsNewRecommend() {
        return isNewRecommend;
    }

    public void setIsNewRecommend(Integer isNewRecommend) {
        this.isNewRecommend = isNewRecommend;
    }

    public Integer getRank() {
        return rank;
    }

    public void setRank(Integer rank) {
        this.rank = rank;
    }

    public String getCategory() {
        return category;
    }

    public void setCategory(String category) {
        this.category = category;
    }

    public Integer getVideoSource() {
        return videoSource;
    }

    public String getChannel() {
        return channel;
    }

    public void setChannel(String channel) {
        this.channel = channel;
    }

    public void setVideoSource(Integer videoSource) {
        this.videoSource = videoSource;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Integer getNewsType() {
        return newsType;
    }

    public void setNewsType(Integer newsType) {
        this.newsType = newsType;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getImageUrl() {
        return imageUrl;
    }

    public void setImageUrl(String imageUrl) {
        this.imageUrl = imageUrl;
    }

    public String getNewsUrl() {
        return newsUrl;
    }

    public void setNewsUrl(String newsUrl) {
        this.newsUrl = newsUrl;
    }

    public String getAuthor() {
        return author;
    }

    public void setAuthor(String author) {
        this.author = author;
    }

    public Long getStarNum() {
        return starNum;
    }

    public void setStarNum(Long starNum) {
        this.starNum = starNum;
    }

    public Long getReadNum() {
        return readNum;
    }

    public void setReadNum(Long readNum) {
        this.readNum = readNum;
    }

    public Integer getVideoTime() {
        return videoTime;
    }

    public void setVideoTime(Integer videoTime) {
        this.videoTime = videoTime;
    }

    public Date getPublishTime() {
        return publishTime;
    }

    public void setPublishTime(Date publishTime) {
        this.publishTime = publishTime;
    }

    public String getAuthorUrl() {
        return authorUrl;
    }

    public void setAuthorUrl(String authorUrl) {
        this.authorUrl = authorUrl;
    }

    public boolean getIsStar() {
        return isStar;
    }

    public void setIsStar(boolean isStar) {
        this.isStar = isStar;
    }

    public Date getRecommendTime() {
        return recommendTime;
    }

    public void setRecommendTime(Date recommendTime) {
        this.recommendTime = recommendTime;
    }

    public Date getOffTime() {
        return offTime;
    }

    public void setOffTime(Date offTime) {
        this.offTime = offTime;
    }

    public Integer getIsRecommend() {
        return isRecommend;
    }

    public void setIsRecommend(Integer isRecommend) {
        this.isRecommend = isRecommend;
    }

    public Long getTagId() {
        return tagId;
    }

    public void setTagId(Long tagId) {
        this.tagId = tagId;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }
}
